import { useEffect, useState } from "react";
import { Card, CardContent } from "@/components/ui/card";
import { Button } from "@/components/ui/button";
import { Badge } from "@/components/ui/badge";
import { Link } from "wouter";
import Navigation from "@/components/navigation";
import SEOHead from "@/components/seo-head";
import { trackSalesInquiry } from "@/lib/facebook-pixel";
import Footer from "@/components/footer";
import { Check, Users, Award, TrendingUp, Calendar, X, Eye } from "lucide-react";
import Cal, { getCalApi } from "@calcom/embed-react";
import walkthrough3DImage from "@assets/Screenshot 2025-06-30 at 21.05.28_1751313937671.png";

export default function SalesPage() {
  const [show3DModal, setShow3DModal] = useState(false);

  useEffect(() => {
    // Lazy load Cal.com API only when component mounts
    const loadCalApi = async () => {
      try {
        const cal = await getCalApi({"namespace":"sales-valuation"});
        cal("ui", {"theme":"light","hideEventTypeDetails":false,"layout":"month_view"});
      } catch (error) {
        console.warn('Cal.com API failed to load:', error);
      }
    };
    
    // Delay Cal.com loading to prioritize critical content
    const timer = setTimeout(loadCalApi, 1000);
    return () => clearTimeout(timer);
  }, [])

  useEffect(() => {
    // Handle anchor scrolling on page load
    const hash = window.location.hash;
    if (hash) {
      const element = document.querySelector(hash);
      if (element) {
        setTimeout(() => {
          element.scrollIntoView({ behavior: 'smooth' });
        }, 100);
      }
    }
  }, [])

  const salesSchema = {
    "@context": "https://schema.org",
    "@type": "Service",
    "name": "Property Sales Services",
    "provider": {
      "@type": "RealEstateAgent",
      "name": "RG Property"
    },
    "description": "Professional property sales services in Bristol and Cardiff with competitive rates from 0.8% + VAT. Expert marketing, photography, and dedicated support.",
    "areaServed": ["Bristol", "Cardiff", "Bath", "Gloucester"],
    "offers": [
      {
        "@type": "Offer",
        "name": "Traditional Sales Package",
        "price": "0.8%",
        "priceCurrency": "GBP"
      },
      {
        "@type": "Offer", 
        "name": "Prestige Sales Package",
        "price": "1%",
        "priceCurrency": "GBP"
      },
      {
        "@type": "Offer",
        "name": "Elite Sales Package", 
        "price": "1.2%",
        "priceCurrency": "GBP"
      }
    ]
  };

  return (
    <div className="min-h-screen bg-white">
      <SEOHead
        title="Property Sales Bristol & Cardiff | Estate Agent Fees from 0.8% | RG Property"
        description="Sell your property in Bristol or Cardiff with RG Property. Competitive fees from 0.8% + VAT, professional marketing, 4K videos, drone footage. Book your free valuation today."
        keywords="property sales Bristol, property sales Cardiff, estate agent fees Bristol, sell house Bristol, sell property Cardiff, property valuation Bristol, estate agent Bristol, property marketing"
        canonicalUrl="https://www.rgproperty.co.uk/sales"
        ogTitle="Property Sales Bristol & Cardiff - Competitive Fees from 0.8%"
        ogDescription="Professional property sales with competitive fees from 0.8% + VAT. Expert marketing, photography, and dedicated support in Bristol and Cardiff."
        schema={salesSchema}
      />
      <Navigation />
      
      {/* Hero Section */}
      <section className="py-16 lg:py-24 bg-gradient-to-br from-gray-900 to-gray-800 text-white">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center">
            <h1 className="text-4xl lg:text-6xl font-bold mb-6">
              SELL YOUR HOME<br />
              <span className="text-red-500">THE RIGHT WAY</span>
            </h1>
            <p className="text-xl text-gray-300 mb-8 max-w-3xl mx-auto">
              Get your property sold quickly and efficiently with our expert sales team and competitive rates.
            </p>
            
            <div className="mb-12">
              <a href="#book-valuation">
                <Button className="bg-red-600 hover:bg-red-700 text-white font-semibold py-3 px-8 rounded-lg transition-colors duration-200">
                  Get Free Valuation
                </Button>
              </a>
            </div>
            
            <p className="text-lg text-gray-300">
              THE ONLY AGENT IN BRISTOL WITH ONLY 5 STAR REVIEWS
            </p>
          </div>
        </div>
      </section>

      {/* Our Sales Services Section */}
      <section className="py-16 lg:py-20 bg-gray-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">OUR SALES SERVICES</h2>
            <div className="w-24 h-1 bg-red-600 mx-auto"></div>
          </div>
          
          <div className="grid lg:grid-cols-4 gap-8">
            {/* Service Cards */}
            <div className="lg:col-span-4 grid md:grid-cols-3 gap-6">
              
              {/* Traditional */}
              <Card className="shadow-lg">
                <CardContent className="p-6 text-center flex flex-col h-full">
                  <div className="mb-6">
                    <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">0.8% <span className="text-lg text-gray-600">+VAT</span></div>
                    <div className="bg-red-600 text-white px-3 py-1 text-xs font-semibold">
                      TRADITIONAL
                    </div>
                  </div>
                  
                  <div className="text-left space-y-2 mb-6 flex-grow">
                    <ul className="text-sm text-gray-700 space-y-1">
                      <li>• Professionally edited marketing photos</li>
                      <li>• Rightmove & Zoopla listing</li>
                      <li>• Social media marketing package</li>
                      <li>• No sale no fee</li>
                      <li>• Dedicated point of contact</li>
                    </ul>
                  </div>
                  
                  <div className="border-t pt-4 mt-auto">
                    <p className="text-xs text-gray-600 mb-4">
                      Subject to minimum fee of <strong>£1,500 + VAT</strong>
                    </p>
                    <a href="#book-valuation">
                      <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                        Book Sales Valuation
                      </Button>
                    </a>
                  </div>
                </CardContent>
              </Card>

              {/* Prestige */}
              <Card className="relative overflow-hidden shadow-lg">
                <div className="absolute top-0 right-0 bg-gray-800 text-white px-3 py-1 text-xs font-bold">
                  POPULAR
                </div>
                <CardContent className="p-6 text-center flex flex-col h-full">
                  <div className="mb-6">
                    <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">1% <span className="text-lg text-gray-600">+VAT</span></div>
                    <div className="bg-gray-800 text-white px-3 py-1 text-xs font-semibold">
                      PRESTIGE
                    </div>
                  </div>
                  
                  <div className="text-left space-y-2 mb-6 flex-grow">
                    <ul className="text-sm text-gray-700 space-y-1">
                      <li>• Professional photography</li>
                      <li>• 4K video tour</li>
                      <li>• Premium Rightmove & Zoopla listing</li>
                      <li>• Paid ad social media marketing package</li>
                      <li>• Free speed tour</li>
                      <li>• No sale no fee</li>
                      <li>• Dedicated point of contact</li>
                    </ul>
                  </div>
                  
                  <div className="border-t pt-4 mt-auto">
                    <p className="text-xs text-gray-600 mb-4">
                      Subject to minimum fee of <strong>£2,000 + VAT</strong>
                    </p>
                    <a href="#book-valuation">
                      <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                        Book Sales Valuation
                      </Button>
                    </a>
                  </div>
                </CardContent>
              </Card>

              {/* Elite */}
              <Card className="shadow-lg">
                <CardContent className="p-6 text-center flex flex-col h-full">
                  <div className="mb-6">
                    <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">1.2% <span className="text-lg text-gray-600">+VAT</span></div>
                    <div className="bg-yellow-600 text-white px-3 py-1 text-xs font-semibold">
                      ELITE
                    </div>
                  </div>
                  
                  <div className="text-left space-y-2 mb-6 flex-grow">
                    <ul className="text-sm text-gray-700 space-y-1">
                      <li>• Professional photography</li>
                      <li>• 4K cinematic video tour (guaranteed 10k+ views)</li>
                      <li>• Aerial drone footage</li>
                      <li>• <button onClick={() => setShow3DModal(true)} className="text-blue-600 hover:text-blue-800 underline">3D House walkthrough</button></li>
                      <li>• Featured Rightmove & Zoopla listing</li>
                      <li>• Ultimate social media marketing package</li>
                      <li>• Free speed tour</li>
                      <li>• No sale no fee</li>
                      <li>• Dedicated point of contact</li>
                    </ul>
                  </div>
                  
                  <div className="border-t pt-4 mt-auto">
                    <p className="text-xs text-gray-600 mb-4">
                      Subject to minimum fee of <strong>£2,500 + VAT</strong>
                    </p>
                    <a href="#book-valuation">
                      <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                        Book Sales Valuation
                      </Button>
                    </a>
                  </div>
                </CardContent>
              </Card>
            </div>
          </div>
          
          {/* Get Free Valuation Button - Below Sales Services */}
          <div className="text-center mt-12">
            <Button 
              className="bg-red-600 hover:bg-red-700 text-white font-semibold px-8 py-4 rounded-lg text-lg transition-colors duration-200"
              onClick={() => {
                const element = document.querySelector('#book-valuation');
                if (element) {
                  element.scrollIntoView({ behavior: 'smooth' });
                }
              }}
            >
              Get Free Valuation
            </Button>
          </div>
        </div>
      </section>

      {/* Why Choose Us Section */}
      <section className="py-16 lg:py-20">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">Why Choose Us?</h2>
            <div className="w-24 h-1 bg-red-600 mx-auto"></div>
          </div>
          
          <div className="grid md:grid-cols-3 gap-8">
            {/* Experience */}
            <Card className="text-center shadow-lg hover:shadow-xl transition-shadow duration-200">
              <CardContent className="p-8">
                <div className="bg-red-100 rounded-full p-4 w-16 h-16 mx-auto mb-6 flex items-center justify-center">
                  <Users className="h-8 w-8 text-red-600" />
                </div>
                <h3 className="text-xl font-semibold text-gray-900 mb-4">Experience</h3>
                <p className="text-gray-600 leading-relaxed">
                  Between the team we have over 50+ years of experience.
                </p>
                <p className="text-gray-600 leading-relaxed mt-2">
                  We know how to get your home sold.
                </p>
              </CardContent>
            </Card>

            {/* A.I */}
            <Card className="text-center shadow-lg hover:shadow-xl transition-shadow duration-200">
              <CardContent className="p-8">
                <div className="bg-red-100 rounded-full p-4 w-16 h-16 mx-auto mb-6 flex items-center justify-center">
                  <Award className="h-8 w-8 text-red-600" />
                </div>
                <h3 className="text-xl font-semibold text-gray-900 mb-4">A.I</h3>
                <p className="text-gray-600 leading-relaxed">
                  We have built in house AI to help chase solicitors, organise viewings to specific times and even give you access to a portal that gives you full control over your sale. This means that you are constantly updated along the way and never left in the dark.
                </p>
              </CardContent>
            </Card>

            {/* Marketing */}
            <Card className="text-center shadow-lg hover:shadow-xl transition-shadow duration-200">
              <CardContent className="p-8">
                <div className="bg-red-100 rounded-full p-4 w-16 h-16 mx-auto mb-6 flex items-center justify-center">
                  <TrendingUp className="h-8 w-8 text-red-600" />
                </div>
                <h3 className="text-xl font-semibold text-gray-900 mb-4">Marketing</h3>
                <p className="text-gray-600 leading-relaxed mb-4">
                  We provide more marketing techniques than any other agent:
                </p>
                <ul className="text-gray-600 text-left space-y-1">
                  <li>- 4K Video Tours</li>
                  <li>- Paid Social Media Advertising</li>
                  <li>- Drone Footage</li>
                  <li>- Speed Tour</li>
                  <li>- Paid Google Ad Campaign</li>
                </ul>
              </CardContent>
            </Card>
          </div>
          
          {/* Get Free Valuation Button - Below Why Choose Us */}
          <div className="text-center mt-12">
            <Button 
              className="bg-red-600 hover:bg-red-700 text-white font-semibold px-8 py-4 rounded-lg text-lg transition-colors duration-200"
              onClick={() => {
                trackSalesInquiry();
                const element = document.querySelector('#book-valuation');
                if (element) {
                  element.scrollIntoView({ behavior: 'smooth' });
                }
              }}
            >
              Get Free Valuation
            </Button>
          </div>
        </div>
      </section>

      {/* We Get Your Home Seen Section */}
      <section className="py-16 lg:py-20 bg-gradient-to-br from-gray-900 to-gray-800 text-white">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid lg:grid-cols-2 gap-12 items-center">
            {/* Left Column - Content */}
            <div>
              <h2 className="text-3xl lg:text-5xl font-bold mb-6">
                We Get Your Home Seen...
              </h2>
              <p className="text-xl text-blue-100 mb-8">
                Our cutting-edge marketing approach ensures maximum exposure for your property across 
                all major platforms and channels.
              </p>
              <div className="space-y-4">
                <div className="flex items-center">
                  <Check className="h-5 w-5 text-green-400 mr-3 flex-shrink-0" />
                  <span>Premium listings on Rightmove and Zoopla</span>
                </div>
                <div className="flex items-center">
                  <Check className="h-5 w-5 text-green-400 mr-3 flex-shrink-0" />
                  <span>Professional photography and virtual tours</span>
                </div>
                <div className="flex items-center">
                  <Check className="h-5 w-5 text-green-400 mr-3 flex-shrink-0" />
                  <span>Targeted social media advertising</span>
                </div>
                <div className="flex items-center">
                  <Check className="h-5 w-5 text-green-400 mr-3 flex-shrink-0" />
                  <span>Local and national property portals</span>
                </div>
              </div>
              <Button 
                className="mt-8 bg-red-600 hover:bg-red-700 text-white font-semibold py-3 px-8 rounded-lg transition-colors duration-200"
                onClick={() => {
                  const element = document.querySelector('#book-valuation');
                  if (element) {
                    element.scrollIntoView({ behavior: 'smooth' });
                  }
                }}
              >
                Get Started Today
              </Button>
            </div>

            {/* Right Column - Visual Element */}
            <div className="relative">
              <div className="bg-red-500 rounded-lg p-8 transform rotate-3 shadow-2xl">
                <div className="bg-white text-gray-900 rounded-lg p-6">
                  <h3 className="text-2xl font-bold mb-4">Your Property Here</h3>
                  <p className="text-gray-600 mb-4">
                    Featured across all major property portals and marketing channels.
                  </p>
                  <div className="flex space-x-2">
                    <Badge variant="secondary">Rightmove</Badge>
                    <Badge variant="secondary">Zoopla</Badge>
                    <Badge variant="secondary">Social Media</Badge>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Calendar Booking Section */}
      <section id="book-valuation" className="py-16 lg:py-20 bg-white">
        <div className="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">
              Book Your Free Property Valuation
            </h2>
            <p className="text-lg text-gray-600 max-w-3xl mx-auto">
              Ready to discover what your property is worth? Schedule a free, no-obligation valuation with one of our expert agents. Choose a time that works for you.
            </p>
          </div>
          
          <div className="grid lg:grid-cols-3 gap-12 items-start">
            {/* Calendar - Takes up 2 columns on desktop */}
            <div className="lg:col-span-2 bg-white rounded-lg shadow-lg p-6">
              <div className="flex items-center mb-6">
                <Calendar className="h-6 w-6 text-red-600 mr-3" />
                <h3 className="text-xl font-semibold text-gray-900">Select Your Appointment</h3>
              </div>
              <div className="min-h-[600px] w-full overflow-hidden">
                <Cal 
                  namespace="sales-valuation"
                  calLink="r-g-property-bristol-qiqxb3/sales-valuation"
                  style={{width:"100%",height:"100%",overflow:"scroll"}}
                  config={{"layout":"month_view","theme":"light"}}
                />
              </div>
            </div>

            {/* Benefits - Takes up 1 column on desktop */}
            <div className="lg:col-span-1 space-y-8">
              <Card className="shadow-lg">
                <CardContent className="p-8">
                  <h3 className="text-xl font-semibold text-gray-900 mb-4">What to Expect</h3>
                  <div className="space-y-4">
                    <div className="flex items-start">
                      <Check className="h-5 w-5 text-green-500 mr-3 mt-1 flex-shrink-0" />
                      <div>
                        <p className="font-medium text-gray-900">Comprehensive Property Assessment</p>
                        <p className="text-sm text-gray-600">Detailed evaluation of your property's current market value</p>
                      </div>
                    </div>
                    <div className="flex items-start">
                      <Check className="h-5 w-5 text-green-500 mr-3 mt-1 flex-shrink-0" />
                      <div>
                        <p className="font-medium text-gray-900">Local Market Analysis</p>
                        <p className="text-sm text-gray-600">Insights into current market trends and comparable sales</p>
                      </div>
                    </div>
                    <div className="flex items-start">
                      <Check className="h-5 w-5 text-green-500 mr-3 mt-1 flex-shrink-0" />
                      <div>
                        <p className="font-medium text-gray-900">Marketing Strategy Discussion</p>
                        <p className="text-sm text-gray-600">Personalised plan to maximise your property's appeal</p>
                      </div>
                    </div>
                    <div className="flex items-start">
                      <Check className="h-5 w-5 text-green-500 mr-3 mt-1 flex-shrink-0" />
                      <div>
                        <p className="font-medium text-gray-900">No Obligation</p>
                        <p className="text-sm text-gray-600">Free consultation with no pressure to sell</p>
                      </div>
                    </div>
                  </div>
                </CardContent>
              </Card>

              <Card className="shadow-lg bg-red-50 border-red-200">
                <CardContent className="p-8">
                  <h3 className="text-xl font-semibold text-red-900 mb-4">Why Choose RG Property?</h3>
                  <div className="space-y-3">
                    <div className="flex items-center">
                      <Award className="h-5 w-5 text-red-600 mr-3" />
                      <span className="text-red-800">ARLA Propertymark Protected</span>
                    </div>
                    <div className="flex items-center">
                      <Users className="h-5 w-5 text-red-600 mr-3" />
                      <span className="text-red-800">Local Bristol property experts</span>
                    </div>
                    <div className="flex items-center">
                      <TrendingUp className="h-5 w-5 text-red-600 mr-3" />
                      <span className="text-red-800">Proven track record of successful sales</span>
                    </div>
                  </div>
                </CardContent>
              </Card>
            </div>
          </div>
        </div>
      </section>

      {/* Property Investment Section */}
      <section className="py-16 lg:py-20 bg-gradient-to-r from-green-50 to-blue-50">
        <div className="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid lg:grid-cols-2 gap-12 items-center">
            <div>
              <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-6">
                Thinking of Buying?
              </h2>
              <p className="text-lg text-gray-600 mb-6">
                We don't just sell properties - we help buyers find their perfect home too. Our extensive network and market knowledge give you access to the best properties in Bristol.
              </p>
              <div className="space-y-3 mb-8">
                <div className="flex items-center">
                  <Check className="h-5 w-5 text-green-500 mr-3" />
                  <span className="text-gray-700">First to know about new listings</span>
                </div>
                <div className="flex items-center">
                  <Check className="h-5 w-5 text-green-500 mr-3" />
                  <span className="text-gray-700">Expert local area advice</span>
                </div>
                <div className="flex items-center">
                  <Check className="h-5 w-5 text-green-500 mr-3" />
                  <span className="text-gray-700">Help with negotiations and offers</span>
                </div>
              </div>
              <Link href="/buy">
                <Button className="bg-blue-600 hover:bg-blue-700 text-white font-semibold py-3 px-8 rounded-lg transition-colors duration-200">
                  View Available Properties
                </Button>
              </Link>
            </div>
            <div className="bg-white rounded-lg shadow-lg p-8">
              <h3 className="text-xl font-semibold text-gray-900 mb-4">Register Your Interest</h3>
              <p className="text-gray-600 mb-4">Get notified about properties that match your criteria before they hit the market.</p>
              <div className="space-y-2 text-sm text-gray-500">
                <div>✓ Early access to new listings</div>
                <div>✓ Personalised property alerts</div>
                <div>✓ Market insights and trends</div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Final CTA Section */}
      <section className="py-16 lg:py-20 bg-gray-900 text-white">
        <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <h2 className="text-3xl lg:text-4xl font-bold mb-6">
            Get Your Free Property Valuation Today
          </h2>
          <p className="text-xl text-gray-300 mb-8">
            No obligation, no pressure. Just honest advice from Bristol's most trusted estate agents.
          </p>
          <div className="flex flex-col sm:flex-row gap-4 justify-center">
            <Button 
              className="bg-red-600 hover:bg-red-700 text-white font-semibold py-4 px-10 rounded-lg text-lg transition-colors duration-200"
              onClick={() => {
                const element = document.querySelector('#book-valuation');
                if (element) {
                  element.scrollIntoView({ behavior: 'smooth' });
                }
              }}
            >
              Book Free Valuation
            </Button>
            <Button 
              variant="outline"
              className="border-2 border-white bg-white text-gray-900 hover:bg-gray-100 font-semibold py-4 px-10 rounded-lg text-lg transition-colors duration-200"
            >
              Call Us Now
            </Button>
          </div>
          <p className="text-gray-400 mt-6 text-sm">
            Available 7 days a week | Free consultation | No hidden fees
          </p>
        </div>
      </section>

      <Footer />
      
      {/* 3D Walkthrough Modal */}
      {show3DModal && (
        <div className="fixed inset-0 bg-black bg-opacity-75 flex items-center justify-center z-50 p-4">
          <div className="bg-white rounded-lg max-w-4xl w-full max-h-[90vh] overflow-auto">
            <div className="flex justify-between items-center p-6 border-b">
              <h3 className="text-2xl font-bold text-gray-900">3D House Walkthrough Example</h3>
              <button
                onClick={() => setShow3DModal(false)}
                className="text-gray-400 hover:text-gray-600 transition-colors"
              >
                <X className="w-6 h-6" />
              </button>
            </div>
            <div className="p-6">
              <img
                src={walkthrough3DImage}
                alt="3D House Walkthrough Example"
                className="w-full h-auto rounded-lg shadow-lg"
              />
              <div className="mt-4 text-center">
                <p className="text-gray-600 mb-4">
                  This immersive 3D walkthrough technology allows potential buyers to explore every room and space virtually, 
                  providing an unparalleled viewing experience that significantly increases engagement and buyer interest.
                </p>
                <p className="text-sm text-gray-500">
                  Available exclusively with our Elite package (1.2% + VAT)
                </p>
              </div>
            </div>
          </div>
        </div>
      )}
    </div>
  );
}